****************************************************************    
* Program name:  followp2.sas                                       
* Project:       Housing Discrimination Study Phase II               
*                                                                   
*  Final version: April 21, 2003 by Steve Ross                    
*                                                                   
*  This program reads the follow-up contact logs and generates      
*  a variable indicating whether that log represents evidence       
*  of follow-up contact.  The logs are compileds by visit in        
*  order to indicate whether a specific tester received follow-up   
*  contact after their participation in a specific test.            
*                                                                   
* Input Files:   followup.ssd01                                     
*                                                                   
* Output Files:  followp2.ssd01                                       
*                                                                   
*                                                                   
****************************************************************;   

options nocenter ;

libname hds2000 '/work/ross/phase3' ;
/* ref file */
filename followup '/work/ross/phase3/followup.ssd01' ;
/* new file */
filename followp2 '/work/ross/phase3/followp3.ssd01' ;

/* load data on followup contact */

data follow ; set hds2000.followup ;

proc contents ;

data follow ; set follow ;
 
  count=1 ;

  if raceid<20 then race=raceid-10 ;
    else if raceid>30 then race=raceid-30 ;
    else race=raceid-20 ;
    

  if delrec=1 then delete ;
  else if raceid>30 then delete ;
  else output follow ;

/* look for duplicate observations */

proc sort data=follow ;
   by control race seqfuc ;

data follow ; set follow  ;
  
  count=1 ;  

  if lcontype=-1 then count=0 ;

  if lyncont=1 or lconname^='' or lagency^='' then count=1 ;

  if lyncont=0 and (lconname='' or lconname='no follow up') and
  (lagency='' or lagency='no follow up') then count=0  ;
   


proc sort ;
  by control race  ;

proc means noprint ;
   var count ;
   by control race  ;
   output out=mfollow2 sum=totcnt2 ;


proc freq ;
  tables totcnt2 ;

proc freq data=mfollow2 ;
  tables totcnt2 ;

/* save cleaned follow up data */

data hds2000.followp3 ;
  set mfollow2 ;
  keep control totcnt2 race ;

data test ; set mfollow2 ;


proc freq ;
  tables type ;

run;





