***************************************************************
* Program name:  rental_output3_tot.sas
* Project:       Housing Discrimination Study Phase II
*
*  Final version: April 28, 2003 by Steve Ross
*
*  This program generates pooled results on adverse treatment
*  of Native Americans across the three rental sites.  The results 
*  are found in table format in the sas list file, rental_output2.lst.
*  
* Input Files:   mrgrp3.ssd01
*
* Output Files:  none
*                                            
****************************************************************;

options nocenter ;

libname hds '/work/ross/phase3' ;

filename mrgrp2 '/work/ross/phase3/mrgrp3.ssd01' ;


/* load data containing site weights based on advertisement 
   volume */

data weight ;
  input nsite $ wpop result $ ;
  cards ;
  AQ 39992 NM
  BL 3950  MT
  DL 4860  MN
  GF 3394  MT
  LC 2580  NM
  MN 21590 MN
  MS 2193  MT
  SA 4089  NM
  ;  


proc print ;

/* scale weights, wpop, so that sum of weights for each
site grouping equals one */  

proc sort ;
  by nsite ;

proc means noprint ;
  var wpop ;
  output out=tweight sum=tpop ;


data weight ;
  set weight ;
  count=1 ;
proc sort ; by count ;


data tweight ;
  set tweight ;
  count=1 ;
proc sort ; by count ;


data weight ;
  merge weight tweight ;
    by count ;
  wpop=wpop/tpop ;


/* read in phase 1 and phase 2 data */

data hds ;
  set hds.mrgrp3 ;

    if nsite in ('AQ', 'LC', 'SA') then result='NM' ;
    if nsite in ('BL', 'GF', 'MS') then result='MT' ;
    if nsite in ('MN', 'DL') then result='MN' ;

proc sort ;
  by nsite ;

data hds ;
  merge hds (in=q1) weight ;
    by nsite ; if q1 ; 
  count=1 ;
  if wrentadi=. then rcount=0 ;
    else rcount=1 ;
  if wsecdepi=. then scount=0 ;
    else scount=1 ;
  if wincent=. or mincent=. then tcount=0 ;
    else tcount=1 ;

proc freq ;
  tables count rcount scount tcount ;

/* calculate the number of valid tests per site for relevant
variables */

proc sort ; by nsite ;

proc means noprint ; 
  var count rcount scount tcount ;
    by nsite ; 
  output out=cnt00 sum=num00 num00r num00s num00t ;


proc means noprint data=hds; 
  var count  rcount scount tcount ;
  output out=cnttot sum=numtot numtotr numtots numtott ;


data hds ;
  merge  hds cnt00 ;
    by nsite ; 

data hds ;
  set hds ;
  count=1 ;
proc sort ; by count ;
data cnttot ;
  set cnttot ;
  count=1 ;
proc sort ; by count ;

data hds ;
  merge  hds cnttot ;
    by count ;

/* create discrete variables for each treatment based on four 
possible outcomes:  both favored, white favored, minority 
favored, and neither favored.  Record neither favored if
we cannot distinguish between both or neither. */

avail11=0 ; avail10=0 ; avail01=0 ; availc=1 ;
if wavailad=1 and mavailad=1 then avail11=1 ;
  else if wavailad=1 and mavailad=0 then avail10=1 ;
  else if wavailad=0 and mavailad=1 then avail01=1 ;

avlsm11=0 ; avlsm10=0 ; avlsm01=0 ; avlsmc=1 ;
if wavailsm=1 and mavailsm=1 then avlsm11=1 ;
  else if wavailsm=1 and mavailsm=0 then avlsm10=1 ;
  else if wavailsm=0 and mavailsm=1 then avlsm01=1 ;

recom11=0 ; recom10=0 ; recom01=0 ; recomc=1 ;
if wrecomi=1 and mrecomi=1 then recom11=1 ;
  else if wrecomi=1 and mrecomi=0 then recom10=1 ;
  else if wrecomi=0 and mrecomi=1 then recom01=1 ;

  /* hierarchical composite for access */

waccess=0 ; maccess=0 ; 
if avail10=1 then waccess=1 ;
  else if avail01=1 then maccess=1 ;
  else if avlsm10=1 then waccess=1 ;
  else if avlsm01=1 then maccess=1 ;
  else if recom10=1 then waccess=1 ;
  else if recom01=1 then maccess=1 ;


  /* consistency composite for access */


wacccns=0 ; macccns=0 ; 
if (avail10=1 or avlsm10=1 or recom10=1) then wacccns=1 ;
if (avail01=1 or avlsm01=1 or recom01=1) then macccns=1 ;

  
inspad11=0 ; inspad10=0 ; inspad01=0 ; inspadc=1 ;
if winspadv=1 and minspadv=1 then inspad11=1 ;
  else if winspadv=1 and minspadv=0 then inspad10=1 ;
  else if winspadv=0 and minspadv=1 then inspad01=1 ;

inspsm11=0 ; inspsm10=0 ; inspsm01=0 ; inspsmc=1 ;
if winspsim=1 and minspsim=1 then inspsm11=1 ;
  else if winspsim=1 and minspsim=0 then inspsm10=1 ;
  else if winspsim=0 and minspsim=1 then inspsm01=1 ;

inspct11=0 ; inspct10=0 ; inspct01=0 ; inspctc=1 ;
if winspcti=1 and minspcti=1 then inspct11=1 ;
  else if winspcti=1 and minspcti=0 then inspct10=1 ;
  else if winspcti=0 and minspcti=1 then inspct01=1 ;

  /* hierarchical composite for inspection */

waccss2=0 ; maccss2=0 ;
if inspad10=1 then waccss2=1 ;
else if inspad01=1 then maccss2=1 ;
else if inspsm10=1 then waccss2=1 ;
else if inspsm01=1 then maccss2=1 ;
else if inspct10=1 then waccss2=1 ;
else if inspct01=1 then maccss2=1 ;

  /* consistency composite for inspection */

wacc2cns=0 ; macc2cns=0 ;
if (inspad10=1 or inspsm10=1 or inspct10=1) then wacc2cns=1 ;
if (inspad01=1 or inspsm01=1 or inspct01=1) then macc2cns=1 ;

                                                       
askfil11=0 ; askfil10=0 ; askfil01=0 ; askfilc=1 ;     
if waskfill=1 and maskfill=1 then askfil11=1 ;         
  else if waskfill=1 and maskfill=0 then askfil10=1 ;  
  else if waskfill=0 and maskfill=1 then askfil01=1 ;  
                                                       
nofutc11=0 ; nofutc10=0 ; nofutc01=0 ; nofutcc=1 ;
if wnofutcn=1 and mnofutcn=1 then nofutc11=1 ;
  else if wnofutcn=1 and mnofutcn=0 then nofutc01=1 ;
  else if wnofutcn=0 and mnofutcn=1 then nofutc10=1 ;

follow11=0 ; follow10=0 ; follow01=0 ; followc=1 ;
if wfollow=1 and mfollow=1 then follow11=1 ;
  else if wfollow=1 and mfollow=0 then follow10=1 ;
  else if wfollow=0 and mfollow=1 then follow01=1 ;

qual11=0 ; qual10=0 ; qual01=0 ; qualc=1 ;
if wqual=1 and mqual=1 then qual11=1 ;
  else if wqual=1 and mqual=0 then qual10=1 ;
  else if wqual=0 and mqual=1 then qual01=1 ;

crdchk11=0 ; crdchk10=0 ; crdchk01=0 ; crdchkc=1 ;
if wcredchk=1 and mcredchk=1 then crdchk11=1 ;
  else if wcredchk=1 and mcredchk=0 then crdchk01=1 ;
  else if wcredchk=0 and mcredchk=1 then crdchk10=1 ;


  /* hierarchical composite for service  */

wservice=0 ; mservice=0 ;
if follow10=1 then wservice=1 ;           
  else if follow01=1 then mservice=1 ;    
  else if askfil10=1 then wservice=1 ;    
  else if askfil01=1 then mservice=1 ;    
  else if crdchk10=1 then wservice=1 ;
  else if crdchk01=1 then mservice=1 ;
  else if nofutc10=1 then wservice=1 ;    
  else if nofutc01=1 then mservice=1 ;    
                                          
  /* consistency composite for service  */


mservcns=0 ; wservcns=0 ;
if (follow10=1 or nofutc10=1 or askfil10=1
   or crdchk10) then wservcns=1 ;
if (follow01=1 or nofutc01=1 or askfil01=1
   or crdchk01=1) then mservcns=1 ;


appfee11=0 ; appfee10=0 ; appfee01=0 ; appfeec=1 ;            
if wappfee=1 and mappfee=1 then appfee11=1 ;                  
  else if wappfee=1 and mappfee=0 then appfee01=1 ;           
  else if wappfee=0 and mappfee=1 then appfee10=1 ;           
  else if wappfee=. or mappfee=. then do ;                    
     appfee11=. ; appfee10=. ; appfee01=. ; appfeec=0 ;       
     end ;                                                    
                                                              
incent11=0 ; incent10=0 ; incent01=0 ; incentc=1 ;            
if wincent=1 and mincent=1 then incent11=1 ;                  
  else if wincent=1 and mincent=0 then incent10=1 ;           
  else if wincent=0 and mincent=1 then incent01=1 ;           
  else if wincent=. or mincent=. then do ;
    incent11=. ; incent10=. ; incent01=. ; incentc=0 ;
    end ;                                             
                 
rentad11=0 ; rentad10=0 ; rentad01=0; rentadc=1 ;             
if wrentadi=1 and mrentadi=1 then rentad11=1 ;                
  else if wrentadi=1 and mrentadi=0 then rentad01=1 ;         
  else if wrentadi=0 and mrentadi=1 then rentad10=1 ;         
  else if wrentadi=. or mrentadi=. then do ;                  
     rentad11=. ; rentad10=. ; rentad01=.; rentadc=0 ;        
     end ;

secdep11=0 ; secdep10=0 ; secdep01=0 ; secdepc=1 ;        
if wsecdepi=1 and msecdepi=1 then secdep11=1 ;            
  else if wsecdepi=1 and msecdepi=0 then secdep01=1 ;     
  else if wsecdepi=0 and msecdepi=1 then secdep10=1 ;     
  else if wsecdepi=. or msecdepi=. then do ;              
     secdep11=. ; secdep10=. ; secdep01=. ; secdepc=0 ;   
     end ;                                                

/* heirarchical composite for terms */

mterms=0 ; wterms=0 ;                  
if rentad10=1 then wterms=1 ;          
  else if rentad01=1 then mterms=1 ;   
  else if incent10=1 then wterms=1 ;   
  else if incent01=1 then mterms=1 ;   
  else if secdep10=1 then wterms=1 ;   
  else if secdep01=1 then mterms=1 ;   
  else if appfee10=1 then wterms=1 ;   
  else if appfee01=1 then mterms=1 ;   
                                       
/* consistency composite for terms */

mtrmcns=0 ; wtrmcns=0 ;                                                     
if (rentad10=1 or incent10=1 or secdep10=1 or appfee10=1) then wtrmcns=1 ;  
if (rentad01=1 or incent01=1 or secdep01=1 or appfee01=1) then mtrmcns=1 ;  



access11=0 ; access10=0 ; access01=0 ; accessc=1 ;
if waccess=1 and maccess=1 then access11=1 ;
if waccess=1 and maccess=0 then access10=1 ;
if waccess=0 and maccess=1 then access01=1 ;

accss211=0 ; accss210=0 ; accss201=0 ; accss2c=1 ;
if waccss2=1 and maccss2=1 then accss211=1 ;
if waccss2=1 and maccss2=0 then accss210=1 ;
if waccss2=0 and maccss2=1 then accss201=1 ;

servic11=0 ; servic10=0 ; servic01=0 ; servicc=1 ;
if wservice=1 and mservice=1 then servic11=1 ;
if wservice=1 and mservice=0 then servic10=1 ;
if wservice=0 and mservice=1 then servic01=1 ;

terms11=0 ; terms10=0 ; terms01=0 ; termsc=1 ;
if wterms=1 and mterms=1 then terms11=1 ;
if wterms=1 and mterms=0 then terms10=1 ;
if wterms=0 and mterms=1 then terms01=1 ;

acccns11=0 ; acccns10=0 ; acccns01=0 ; acccnsc=1 ;
if wacccns=1 and macccns=1 then acccns11=1 ;
if wacccns=1 and macccns=0 then acccns10=1 ;
if wacccns=0 and macccns=1 then acccns01=1 ;

ac2cns11=0 ; ac2cns10=0 ; ac2cns01=0 ; ac2cnsc=1 ;
if wacc2cns=1 and macc2cns=1 then ac2cns11=1 ;
if wacc2cns=1 and macc2cns=0 then ac2cns10=1 ;
if wacc2cns=0 and macc2cns=1 then ac2cns01=1 ;

srvcns11=0 ; srvcns10=0 ; srvcns01=0 ; srvcnsc=1 ;
if wservcns=1 and mservcns=1 then srvcns11=1 ;
if wservcns=1 and mservcns=0 then srvcns10=1 ;
if wservcns=0 and mservcns=1 then srvcns01=1 ;

trmcns11=0 ; trmcns10=0 ; trmcns01=0 ; trmcnsc=1 ;
if wtrmcns=1 and mtrmcns=1 then trmcns11=1 ; 
if wtrmcns=1 and mtrmcns=0 then trmcns10=1 ; 
if wtrmcns=0 and mtrmcns=1 then trmcns01=1 ; 

/* overall consistency composite */

cnsty11=0 ; cnsty10=0 ; cnsty01=0 ; cnstyc=1 ;
if (wtrmcns=1 or wservcns=1 or wacccns=1 or wacc2cns=1) and
   (mtrmcns=1 or mservcns=1 or macccns=1 or macc2cns=1)
      then cnsty11=1 ; 
else if (wtrmcns=1 or wservcns=1 or wacccns=1 or wacc2cns=1)
     and mtrmcns=0 and
     mservcns=0 and macccns=0 and macc2cns=0  then cnsty10=1 ;
else if (mtrmcns=1 or mservcns=1 or macccns=1 or macc2cns=1)
     and wtrmcns=0 and
     wservcns=0 and wacccns=0 and wacc2cns=0  then cnsty01=1 ;

/* variable by variable construction of composite indicator */

heir11=0 ; heir10=0 ; heir01=0 ; heirc=1 ;
if avail10=1 then do ; 
  heir10=1 ;
  end ;
  else if avail01=1 then do ; 
  heir01=1 ;
  end ;
  else if inspad10=1 then do ;
  heir10=1 ;
  end ;
  else if inspad01=1 then do ;
  heir01=1 ;
  end ;
  else if rentad10=1 then do ;
  heir10=1 ;
  end ;
  else if rentad01=1 then do ;
  heir01=1 ;
  end ;
  else if avlsm10=1 then  do ;
  heir10=1 ;
  end ;
  else if avlsm01=1 then  do ;
  heir01=1 ;
  end ;
  else if inspsm10=1 then do ;
  heir10=1 ;
  end ;
  else if inspsm01=1 then do ;
  heir01=1 ;
  end ;
  else if recom10=1 then  do ;
  heir10=1 ;
  end ;
  else if recom01=1 then  do ;
  heir01=1 ;
  end ;
  else if inspct10=1 then do ;
  heir10=1 ;
  end ;
  else if inspct01=1 then do ;
  heir01=1 ;
  end ;
  else if incent10=1 then do ;
  heir10=1 ;
  end ;
  else if incent01=1 then do ;
  heir01=1 ;
  end ;
  else if secdep10=1 then do ;
  heir10=1 ;
  end ;
  else if secdep01=1 then do ;
  heir01=1 ;
  end ;
  else if appfee10=1 then do ; 
  heir10=1 ;
  end ;
  else if appfee01=1 then do ; 
  heir01=1 ;
  end ;
  else if follow10=1 then do ;
  heir10=1 ;
  end ;
  else if follow01=1 then do ;
  heir01=1 ;
  end ;
  else if askfil10=1 then do ; 
  heir10=1 ;
  end ;
  else if askfil01=1 then do ; 
  heir01=1 ;
  end ;
  else if crdchk10=1 then do ;
  heir10=1 ;
  end ;
  else if crdchk01=1 then do ;
  heir01=1 ;
  end ;
  else if nofutc10=1 then  do ;
  heir10=1 ;
  end ;
  else if nofutc01=1 then  do ;
  heir01=1 ;
  end ;
  else heir11=1 ;

/* black white tests */


data hds ;
   set hds ;

/* population based weights for sites */

  nweight=wpop*numtot/num00 ;
  if wrentadi=. then rweight=0 ;
    else   rweight=wpop*numtotr/num00r ;
  if wsecdepi=. then sweight=0 ;
    else   sweight=wpop*numtots/num00s ;
  if wincent=. or mincent=. then tweight=0 ;
    else   tweight=wpop*numtott/num00t ;

  count=1 ;

/* create an individual data set that contains the incidence
for each treatment variables */

proc means sum ;
  var count nweight rcount rweight scount sweight tcount tweight ;


proc means noprint data=hds ; 
   var avail11 avail10 avail01 availc ;
   output out=avail mean=equal white black sum=c11 c10 c01 valid ;
   weight nweight ;

data avail ;
  set avail ;
  variable='availadv' ;
  count=1 ;

proc means noprint  data=hds ; 
   var avlsm11 avlsm10 avlsm01  avlsmc ;
   output out=avlsm mean=equal white black sum=c11 c10 c01 valid ;
   weight nweight ;


data avlsm ;
  set avlsm ;
  variable='availsim' ;
  count=2 ;

proc means noprint  data=hds ; 
   var recom11 recom10 recom01 recomc ;
   output out=recom mean=equal white black  sum=c11 c10 c01 valid ;
   weight nweight ;

data recom ;
  set recom ;
  variable='recom' ;
  count=3 ;

proc means noprint  data=hds ; 
   var access11 access10 access01 accessc ;
   output out=access mean=equal white black  sum=c11 c10 c01 valid ;
   weight nweight ;

data access ;
  set access ;
  variable='access' ;
  count=4 ;

proc means noprint  data=hds ; 
   var acccns11 acccns10 acccns01 acccnsc ;
   output out=acccns mean=equal white black  sum=c11 c10 c01 valid ;
   weight nweight ;

data acccns ;
  set acccns ;
  variable='acccns' ;
  count=5 ;



proc means noprint  data=hds ; 
   var inspad11 inspad10 inspad01 inspadc ;
   output out=inspad mean=equal white black sum=c11 c10 c01 valid ;
   weight nweight ;


data inspad ;
  set inspad ;
  variable='inspad' ;
  count=6 ;

proc means noprint  data=hds ; 
   var inspsm11 inspsm10 inspsm01 inspsmc ;
   output out=inspsm mean=equal white black  sum=c11 c10 c01 valid ;
   weight nweight ;

data inspsm ;
  set inspsm ;
  variable='inspsm' ;
  count=7 ;

proc means noprint  data=hds ; 
   var inspct11 inspct10 inspct01 inspctc ;
   output out=inspct mean=equal white black  sum=c11 c10 c01 valid ;
   weight nweight ;

data inspct ;
  set inspct ;
  variable='inspect' ;
  count=8 ;

proc means noprint  data=hds ; 
   var accss211 accss210 accss201 accss2c ;
   output out=access2 mean=equal white black  sum=c11 c10 c01 valid ;
   weight nweight ;

data access2 ;
  set access2 ;
  variable='access2' ;
  count=9 ;


proc means noprint  data=hds ; 
   var ac2cns11 ac2cns10 ac2cns01 ac2cnsc ;
   output out=acc2cns mean=equal white black  sum=c11 c10 c01 valid ;
   weight nweight ;

data acc2cns ;
  set acc2cns ;
  variable='acc2cns' ;
  count=10 ;

proc means noprint  data=hds ;                                  
   var rentad11 rentad10 rentad01 rentadc ;                         
   output out=rentad mean=equal white black sum=c11 c10 c01 valid ; 
   weight rweight ;                                                 
                                                                    
data rentad ;                                                       
  set rentad ;                                                      
  variable='rentad' ;                                               
  count=11 ;                                                        

                                                                    
proc means noprint  data=hds ;                                  
   var incent11 incent10 incent01 incentc ;                         
   output out=incent mean=equal white black sum=c11 c10 c01 valid ; 
   weight tweight ;                                                  
                                                                   
                                                                    
data incent ;                                                       
  set incent ;                                                      
  variable='incent' ;                                               
  count=12 ;                                                        
                                                                    
                                                                    
                                                                    
proc means noprint  data=hds ;                                  
   var secdep11 secdep10 secdep01 secdepc ;                         
   output out=secdep mean=equal white black sum=c11 c10 c01 valid ; 
   weight sweight ;                                                 
                                                                    
                                                                    
data secdep ;                                                       
  set secdep ;                                                      
  variable='secdep' ;                                               
  count=13 ;                                                        
                                                                    
proc means noprint  data=hds ;                                  
   var appfee11 appfee10 appfee01 appfeec ;                         
   output out=appfee mean=equal white black sum=c11 c10 c01 valid ; 
   weight tweight ;                                                  
                                                                    
data appfee ;                                                       
  set appfee ;                                                      
  variable='appfee' ;                                               
  count=14 ;                                                        
                                                                    
                                                                    
proc means noprint  data=hds ;                                  
   var terms11 terms10 terms01 termsc ;                             
   output out=terms mean=equal white black sum=c11 c10 c01 valid ; 
   weight nweight ;                                                 
                                                                   
                                                                   
data terms ;                                                       
  set terms ;                                                      
  variable='terms' ;                                               
  count=15 ;                                                       
                                                                   
                                                                   
proc means noprint  data=hds ;                                 
   var trmcns11 trmcns10 trmcns01 trmcnsc ;                        
   output out=trmcns mean=equal white black sum=c11 c10 c01 valid ;
   weight nweight ;                                                 
                                                                   
                                                                   
data trmcns ;                                                      
  set trmcns ;                                                     
  variable='trmcns' ;                                              
  count=16 ; 

proc means noprint  data=hds ; 
   var follow11 follow10 follow01 followc ;
   output out=follow mean=equal white black sum=c11 c10 c01 valid  ;
   weight nweight ;


data follow ;
  set follow ;
  variable='follow' ;
  count=17 ;


proc means noprint  data=hds ;                                   
   var askfil11 askfil10 askfil01 askfilc ;                          
   output out=askfil mean=equal white black sum=c11 c10 c01 valid ;  
   weight nweight ;                                                   
                                                                     
                                                                     
data askfil ;                                                        
  set askfil ;                                                       
  variable='askfill' ;                                               
  count=18 ;                                                         

proc means noprint  data=hds ;                                   
   var crdchk11 crdchk10 crdchk01 crdchkc ;                          
   output out=crdchk mean=equal white black sum=c11 c10 c01 valid ;  
   weight nweight ;                                                   
                                                                     
                                                                     
data crdchk ;                                                        
  set crdchk ;                                                       
  variable='crdchk' ;                                               
  count=19 ;                                                         


proc means noprint  data=hds ; 
   var qual11 qual10 qual01 qualc ;
   output out=qual mean=equal white black sum=c11 c10 c01 valid  ;
   weight nweight ;


data qual ;
  set qual ;
  variable='qual' ;
  count=21 ;



proc means noprint  data=hds ; 
   var nofutc11 nofutc10 nofutc01 nofutcc;
   output out=nofutcon mean=equal white black  sum=c11 c10 c01 valid ;
   weight nweight ;


data nofutcon ;
  set nofutcon ;
  variable='nofutcon' ;
  count=20 ;



proc means noprint  data=hds ; 
   var servic11 servic10 servic01 servicc ;
   output out=servic mean=equal white black sum=c11 c10 c01 valid  ;
   weight nweight ;


data servic ;
  set servic ;
  variable='service' ;
  count=22 ;



proc means noprint  data=hds ; 
   var srvcns11 srvcns10 srvcns01 srvcnsc ;
   output out=servcns mean=equal white black sum=c11 c10 c01 valid  ;
   weight nweight ;

data servcns ;
  set servcns ;
  variable='servcns' ;
  count=23 ;


proc means noprint  data=hds ; 
   var heir11 heir10 heir01 heirc ;
   output out=heir mean=equal white black sum=c11 c10 c01 valid  ;
   weight nweight ;


data heir ;
  set heir ;
  variable='heir' ;
  count=24 ;

proc means noprint  data=hds ; 
   var cnsty11 cnsty10 cnsty01 cnstyc ;
   output out=cnsty mean=equal white black sum=c11 c10 c01 valid  ;
   weight nweight ;


data cnsty ;
  set cnsty ;
  variable='cnsty' ;
  count=25 ;

/* create sample of treatment variables for 1989 */

data stat ;
  set avail avlsm inspad inspsm recom inspct 
      follow nofutcon askfil crdchk
      rentad secdep incent appfee
      acccns acc2cns 
      servic access access2 terms
      servcns trmcns cnsty heir ;
  net=white-black ;
  probw=equal+white ;
  probb=equal+black ;
  cprobw=white*valid ;
  cprobb=black*valid ;
  if cprobw+cprobb=0 then cstat=0 ;
  else cstat=(cprobw-cprobb)*(cprobw-cprobb)/(cprobw+cprobb) ;
  var=(probw*(1-probw) + probb*(1-probb) - 2 * (equal * ( 1 -
   equal - white - black) - white*black) ) / valid ;
  sd=var**0.5 ;
  tstat=net/sd ;
  if tstat<0 then tstat=-tstat ;
  cprob=probchi(cstat,1) ;
  nprob=1-2*(1-probnorm(tstat)) ;

proc sort ;
    by count ; 

data stat ;
  set stat ;
   keep variable white black net cprob valid nprob ;

proc print ;



run;







