****************************************************************     
* Program name:  sales_merge_p3.sas                                     
* Project:       Housing Discrimination Study Phase III                
*                                                                    
*  Final version: May 1, 2003 by Steve Ross                     
*                                                                    
*  This program merges together the final sample of sales tests      
*  with counts and means from the sample of rental units recommended 
*  or inspected by the testers, as well as information on whether    
*  follow-up contact was made by the real estate agent.  
*                                                                    
* Input Files:   assignp3.ssd01 salesp3.ssd01, followp3.ssd01, rechomes.ssd01
*                                                                    
* Output Files:  mrgsp3.ssd01                                      
*                                                                    
****************************************************************;    

options nocenter ;

libname hds2000 '/work/ross/phase3' ;

/* ref files */

filename assignp3 '/work/ross/phase3/assignp3.ssd01' ;
filename salesp3 '/work/ross/phase3/salesp3.ssd01' ;
filename followp3 '/work/ross/phase3/followp3.ssd01' ;
filename rechomes '/work/ross/phase3/rechomes.ssd01' ;
filename tester '/work/ross/phase3/tester.ssd01' ;

/* new file */

filename mrgsp2 '/work/ross/phase3/mrgsp3.ssd01' ;


/*------------loading assign, unit,follow, and tests------------------------*/


data tester ; set hds2000.tester ;
  mtestid=testerid ;
  maccent=taccent ;
  masiang=tasiang ;
  keep mtestid maccent masiang ;
proc sort ;
  by mtestid ;

/* load (finalp2=assign) */

data assign ; set hds2000.assignp3 ;

/* load (salesp2=test) */

data tests ; set hds2000.salesp3 ;

/* load (rechp2=unit) */

data unit ; set hds2000.rechomes ;

/* load (folllowp2=follow) */
 
data follow ; set hds2000.followp3 ;

  if totcnt2>0 then follow=1 ;
  else follow=0 ;

  keep control race follow ;

proc sort ;
  by control race ;

/* load assignments */

data assign1 ; set assign ;

/* develop average measures of assignments */

  if wbedmin=0 then wbedmin=. ;
  if mbedmin=0 then mbedmin=. ;

  if wbedmin=. and mbedmin=. then abedmin=. ;
    else if wbedmin=. then abedmin=mbedmin ;      
    else if mbedmin=. then abedmin=wbedmin ;
    else abedmin=min(wbedmin, mbedmin) ;
  if abedmin=0.5 then abedmin=0 ;

  if wbedreq=0 then wbedreq=. ;
  if mbedreq=0 then mbedreq=. ;

  if wbedreq=. and mbedreq=. then do ;
       abedreql=. ;
       abedrequ=. ;
       end ;
    else if wbedreq=. then do ;
       abedreql=mbedreq ;
       abedrequ=mbedreq ;
       end ;
    else if mbedreq=. then do ;
       abedreql=wbedreq ;  
       abedrequ=wbedreq ;  
       end ;
    else do ;
       abedreql=min(wbedreq, mbedreq) ; 
       abedrequ=max(wbedreq, mbedreq) ;   
       end ; 

  abedreql=int(abedreql-.1) ;
  abedrequ=int(abedrequ+.1) ;
   
  if substr(control,4,1)='S' then output assign1 ;
  else delete ;
  keep control abedreql abedrequ abedmin ;

proc sort ;
  by control ;

/* Load unit */

data unit ; set unit ;
 
proc sort ;  by control ;

/* merge average assignments with recommended homes sample */

data unit ;
merge unit (in=q1) assign1 ;
by control ; if q1 ;

  if hbedrms=0 then hbedrms=. ;
  if haskpri=0 then haskpri=. ;

  count=1 ;


data unit ; set unit ;

  /*  size  */  
  
  if abedreql<=hbedrms<=abedrequ or hbedrms=. or abedreql=. then meetbreq=1 ;
     else meetbreq=0 ;

  if hbedrms+0.5>=abedmin then meetbmin=1 ;
    else if meetbreq=1 then meetbmin=1 ;
    else meetbmin=0 ;


  /* advertised unit and inspection */
  
  if hadhome=1 then advunit=1 ;
    else advunit=0 ;
  if hinspct=1 then inspect=1 ;
    else inspect=0 ;
  if inspect=1 and advunit=1 then inspadv=1 ;
    else inspadv=0 ;
  if advunit=1 and meetbreq=1 then advmeet=1 ; 
    else advmeet=0 ;
  if advunit=1 and meetbmin=1 and advmeet=0 then advacc=1 ; 
    else advacc=0 ;
  if advunit=1 then advaskp=haskpri ;
     else advaskp=. ;

  /* similar unit and inspection */

  if meetbreq=1 and advunit=0 then similar=1 ;
    else similar=0 ;
  if inspect=1 and similar=1 then inspsim=1 ;
    else inspsim=0 ;
 
  /* acceptable unit and inspection */

  if meetbmin=1 and advunit=0 and similar=0 then accept=1 ;
    else accept=0 ;
  if inspect=1 and accept=1 then inspacc=1 ;
    else inspacc=0 ;

  if raceid<20 then race=raceid-10 ;
    else if raceid>30 then race=raceid-30 ;
    else race=raceid-20 ;

  if raceid>30 then delete ;
    else output unit ;



proc sort data=unit ;
  by control race ;


/* create counts of units for each visit  */


proc freq ;
  tables  count inspect advunit inspadv advmeet advacc 
      similar inspsim accept inspacc ;


proc means noprint data=unit ;
  by control race ;
  var count inspect advunit inspadv advmeet advacc 
      similar inspsim accept inspacc ;
  output out=sumunit sum=number numinsp numadv advinsp advmtm 
    advaccm numsim siminsp numacc accinsp ;

proc freq ;
  tables number numinsp numadv advinsp advmtm 
    advaccm numsim siminsp numacc accinsp ;

data wunits ;  set sumunit ;
  wnuminsp=numinsp ;
  wnumadv=numadv ;
  wadvmtm=advmtm ;
  wadvacc=advaccm ;
  wadvinsp=advinsp ;
  wnumacc=numacc ;
  wnumsim=numsim ;
  wsiminsp=siminsp ;

if race=1 then output wunits ;
else delete ;   
keep control wnuminsp wadvmtm wadvacc wadvinsp 
wnumacc wnumadv wnumsim wsiminsp ;

proc sort  ;
  by control ;

data munits ;  set sumunit ;
  mnuminsp=numinsp ;
  mnumadv=numadv ;
  madvmtm=advmtm ;
  madvacc=advaccm ;
  madvinsp=advinsp ;
  mnumacc=numacc ;
  mnumsim=numsim ;
  msiminsp=siminsp ;

if race^=1 then output munits ;
else delete ;   
keep control mnuminsp madvmtm madvacc madvinsp 
mnumacc mnumadv mnumsim msiminsp ;

proc sort ;
  by control ;


/*---------------------with follow---------------------*/

data wfollow ; set follow ;
  
  wfollow=follow ;

if race=1 then output wfollow ;
else delete ; 
keep control wfollow ;

proc sort ; by control ;


data mfollow ; set follow ;
  
  mfollow=follow ;

if race^=1 then output mfollow ;
else delete ; 
keep control mfollow  ;

proc sort ; by control ;


data tests ;
merge tests (in=q1) wunits munits wfollow mfollow ;
  by control  ;
if q1 ;


data tests ; set tests ;

/* create treatment variables */


  if wnuminsp=. then wnuminsp=0 ;
  if wadvinsp=. then wadvinsp=0 ;
  if wsiminsp=. then wsiminsp=0 ;
  if wnumadv=. then wnumadv=0 ;
  if wadvmtm=. then wadvmtm=0 ;
  if wadvacc=. then wadvacc=0 ;
  if wnumsim=. then wnumsim=0 ;
  if wnumacc=. then wnumacc=0 ;
  if wfollow=. then wfollow=0 ;

  if mnuminsp=. then mnuminsp=0 ;
  if madvinsp=. then madvinsp=0 ;
  if msiminsp=. then msiminsp=0 ;
  if mnumadv=. then mnumadv=0 ;
  if madvmtm=. then madvmtm=0 ;
  if madvacc=. then madvacc=0 ;
  if mnumsim=. then mnumsim=0 ;
  if mnumacc=. then mnumacc=0 ;
  if mfollow=. then mfollow=0 ;


/* advertised unit available */
/* steve can we just do the following to keep what we have ? since it might
save us correcting all the variables in the program */

  if wavladva=1 or wavladvb=1 then wavailad=1 ;
    else if wavladva=2 or wavladvb=2 then wavailad=0 ;
    else if wadvmtm>0 then wavailad=1 ;
    else wavailad=0 ;

  if mavladva=1 or mavladvb=1 then mavailad=1 ;
    else if mavladva=2 or mavladvb=2 then mavailad=0 ;
    else if madvmtm>0 then mavailad=1 ;
    else mavailad=0 ;


/* similar unit available */

  if wsmbeda=1 or wsmbedb=1 then wavailsm=1 ;
    else if wsmbeda=2 or wsmbedb=2 then wavailsm=0 ;
    else if wnumsim>0 then wavailsm=1 ;
      else wavailsm=0 ;

  if msmbeda=1 or msmbedb=1 then mavailsm=1 ;
    else if msmbeda=2 or msmbedb=2 then mavailsm=0 ;
    else if mnumsim>0 then mavailsm=1 ;
      else mavailsm=0 ;

/*  Advertised unit inspected */

   if wadvinsp=0 then winspadv=0 ;
     else winspadv=1 ;
   if madvinsp=0 then minspadv=0 ;
     else minspadv=1 ;

/*  Similar unit inspected */

   if wsiminsp=0 then winspsim=0 ;
     else winspsim=1 ;

   if msiminsp=0 then minspsim=0 ;
     else minspsim=1 ;

/*  Number of units recommended */

   if wtunita=-1 then wtunita=. ;
   if wtunitb=-1 or wtunitb=. then wtunitb=0 ;
   if mtunita=-1 then mtunita=. ;
   if mtunitb=-1 or mtunitb=. then mtunitb=0 ;

   if wtunita^=. then wrecom=wtunita+wtunitb ;
     else wrecom=wadvmtm+wadvacc+wnumsim+wnumacc ;

   if mtunita^=. then mrecom=mtunita+mtunitb ;
     else mrecom=madvmtm+madvacc+mnumsim+mnumacc ;

  wrecomi=0 ;
  mrecomi=0 ;
  if mrecom>wrecom then mrecomi=1 ;
  if mrecom<wrecom then wrecomi=1 ;

/*  Number of units inspected */

  winspect=wnuminsp ;
  minspect=mnuminsp ;

  winspcti=0 ;
  minspcti=0 ;
  if minspect>winspect then minspcti=1 ;
  if minspect<winspect then winspcti=1 ;
   

/*  Agent asked about finances */


wqincome=wqinca ; wqincom2=wqincb ;
mqincome=mqinca ; mqincom2=mqincb ;

wqasset=wqasseta ; wqasset2=wqassetb ;
mqasset=mqasseta ; mqasset2=mqassetb ;

wqdebts=wqdebtsa ; wqdebts2=wqdebtsb ;
mqdebts=mqdebtsa ; mqdebts2=mqdebtsb ;

wqdownp=wqdownpa ; wqdownp2=wqdownpb ;
mqdownp=mqdownpa ; mqdownp2=mqdownpb ;

wqcredit=wqcreda ; wqcredi2=wqcredb ;
mqcredit=mqcreda ; mqcredi2=mqcredb ;

   if (wqincome=2 or wqincom2=2) and 
      (wqasset=2 or wqasset2=2 or 
      wqdebts=2 or wqdebts2=2 or wqcredit=2 or wqcredi2=2) then 
      waskfin=1 ;
         else waskfin=0 ;

   if (mqincome=2 or mqincom2=2) and 
      (mqasset=2 or mqasset2=2 or 
      mqdebts=2 or mqdebts2=2 or mqcredit=2 or mqcredi2=2) then 
      maskfin=1 ;
         else maskfin=0 ;


/*  Agent said tester qualified */

   if wagquala=1 or wagqualb=1 then wqual=1 ;
      else wqual=0 ;

   if magquala=1 or magqualb=1 then mqual=1 ;
      else mqual=0 ;



/*   asked about prequal */

   if waskbnka=1 or waskbnkb=1 then waskpreq=1 ;
     else waskpreq=0 ;

   if maskbnka=1 or maskbnkb=1 then maskpreq=1 ;
     else maskpreq=0 ;


/*  require prequal */
  
   if wtelbnka=1 or wtelbnkb=1 then wreqpreq=1 ;
     else wreqpreq=0 ;

   if mtelbnka=1 or mtelbnkb=1 then mreqpreq=1 ;
     else mreqpreq=0 ;


/*  offered financial assistence */

   if wagfinda=1 or wagfindb=1 then wfinhelp=1 ;
     else wfinhelp=0 ;

   if magfinda=1 or magfindb=1 then mfinhelp=1 ;
     else mfinhelp=0 ;

/*  provided names of lenders */

   if waglndra=1 or waglndrb=1 then wlenders=1 ;
     else wlenders=0 ;

   if maglndra=1 or maglndrb=1 then mlenders=1 ;
     else mlenders=0 ;


/*  Lender prequalified tester */

   if wpquala=1 or wpqualb=1 then wprequal=1 ;
     else wprequal=0 ;

   if mpquala=1 or mpqualb=1 then mprequal=1 ;
     else mprequal=0 ;


/*  No provision made for future contact */

   if warngm3a=1 then wnofutcn=1 ;
       else wnofutcn=0 ;
   if marngm3a=1 then mnofutcn=1 ;
       else mnofutcn=0 ;


   year='2000';
   count=1 ;

if wsmbedb=. then wsmbedb=4 ;
if msmbedb=. then msmbedb=4 ;


proc freq ;
  tables wnumadv wadvinsp  wnumsim wsiminsp  wsmbeda*wsmbedb wavailsm
     winspsim
     mnumadv madvinsp  mnumsim msiminsp  msmbeda*msmbedb mavailsm
     minspsim ;

data tests ;
  set tests ; 

keep control ngroup nsite 
wavailad mavailad
wavailsm mavailsm
winspadv minspadv
winspsim minspsim
winspect minspect
wrecom mrecom
winspcti minspcti
wrecomi mrecomi
wfollow mfollow
wqual mqual
waskfin maskfin
waskpreq maskpreq
wreqpreq mreqpreq
wfinhelp mfinhelp
wlenders mlenders
wprequal mprequal
wnofutcn mnofutcn 
mtestid wtestid ;

proc freq ;
  tables   winspect minspect wrecom mrecom 
wavailad*mavailad
wavailsm*mavailsm
winspadv*minspadv
winspsim*minspsim
winspcti*minspcti
wrecomi*mrecomi
wfollow*mfollow
wqual*mqual
waskfin*maskfin
waskpreq*maskpreq
wreqpreq*mreqpreq
wfinhelp*mfinhelp
wlenders*mlenders
wprequal*mprequal
wnofutcn*mnofutcn  ;



data hds2000.mrgsp3 ;
  set tests ; 
run;

